#! /bin/sh 

# Check Environmental Parameters
if [ `env | grep STARLINKPATH |gawk 'END{print(NR)}'` -eq 0 ]; then
 echo "Error : Environmental parameter STARLINKPATH not defined."
 echo '        Set it to be the path of the "star" directory.'
 exit 1
fi

if [ ! -f $STARLINKPATH/bin/convert/ndf2fits ]; then
 echo "Error : $STARLINKPATH/bin/convert/ndf2fits does not exist."
 echo '        Check the environment parameter STARLINKPATH '
 exit 1
fi 

if [ ! -d ${STARLINKPATH}/lib ]; then
 echo "Error : $STARLINKPATH/lib does not exist."
 echo '        Check the environment parameter STARLINKPATH '
 exit 1
fi 

if [ `env | grep IMCOPYPATH |gawk 'END{print(NR)}'` -eq 0 ]; then
 echo "Warning : Environmental parameter IMCOPYPATH not defined."
 IMCOPYPATH=`which imcopy | sed 's/\/imcopy$//g'`
# echo $IMCOPYPATH
 STATUS=`echo $IMCOPYPATH | gawk '{print(NR)}'`
# echo $STATUS
 if [ $STATUS -lt 1 ]; then
   echo "Error : No imcopy found."
   exit 1
 fi 
 echo "          Set to $IMCOPYPATH ."
fi

#Check command arguments
if [ ! -d $STARLINKPATH ]; then
    echo "Error : Directory $STARLINKPATH does not exist."
    exit 1
fi

#Check command arguments
if [ $# != 2 ]; then
    echo "Usage : "$0" (input directory) (output directory)"
    exit 1
fi

INDIR=$1
OUTDIR=$2
WORKDIR=/tmp/${USER}-ndftofits

# setup filenames
TMPLIST=$WORKDIR/tmp.list
TMPSH=$WORKDIR/tmp.sh
NDFTOFITSLOG=ndftofits.`date +%y%m%d%H%M%S`.log

# Check Architecture
ARCH=`uname`
echo "# Running on "`uname -a`
echo "# Running on "`uname -a` >> $NDFTOFITSLOG

if [ -f $TMPSH ]; then
 \rm $TMPSH
fi

# Set Temporary directory
if [ ! -d $WORKDIR ];then
  mkdir $WORKDIR
fi

# Set Starlink Library Path
LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${STARLINKPATH}/lib
export LD_LIBRARY_PATH

#Start time
if [ $ARCH = "Linux" ]; then
    SECSTART=`date +%s` 
else 
    SECSTART=`date +"%d %H %M %S"| gawk '{print($1*24*3600+$2*3600+$3*60+$4)}'` 
fi
echo "# Start at $SECSTART" >> $NDFTOFITSLOG
echo "# Start at $SECSTART"


# Execute
ls $INDIR | grep ".sdf.gz$" | while read line; do
 OUTFITS=$OUTDIR/`echo $INDIR/$line | gawk '{n=split($1,a,"/");split(a[n],b,".gz$");outfits=b[1];gsub(".sdf$",".fit",outfits);print(outfits)}'`
 TMPFITS=$WORKDIR/tmp.fits
 TMPSDF=$WORKDIR/tmp.sdf
 echo ""
 echo INPUT=$INDIR/$line >> $NDFTOFITSLOG
 echo OUTPUT=$OUTFITS >> $NDFTOFITSLOG
 echo INPUT=$INDIR/$line
 echo OUTPUT=$OUTFITS
# echo $TMPFITS
# echo $TMPSDF
 if [ -f $TMPFITS ]; then
  rm $TMPFITS
 fi
 if [ -f $OUTFITS ]; then
  rm $OUTFITS
 fi
 gzip -cd $INDIR/$line > $TMPSDF
 $STARLINKPATH/bin/convert/ndf2fits $TMPSDF $TMPFITS merge container >> $NDFTOFITSLOG
 $IMCOPYPATH/imcopy $TMPFITS "$OUTFITS[compress]" >> $NDFTOFITSLOG
done


# Create command file
#echo cd $WORKDIR >> $TMPSH
#ls $INDIR/*.sdf.gz > $TMPLIST
#gawk -v workdir=$WORKDIR -v stardir=$STARLINKPATH -v outdir=$OUTDIR 'BEGIN{print("#! /bin/sh -f ")}{n=split($1,a,"/");split(a[n],b,".gz$");outfits=b[1];gsub(".sdf$",".fit",outfits);printf("if [ -f %s/tmp.fits ]; then\n rm %s/tmp.fits\nfi\n",workdir,workdir);printf("if [ -f %s/%s ]; then\n rm %s/%s\nfi\n",outdir,outfits,outdir,outfits);printf("gzip -cd %s > %s/%s\n",$1,workdir,b[1]);printf("%s/star/bin/convert/ndf2fits %s/%s %s/tmp.fits merge container\n",stardir,workdir,b[1],workdir);printf("imcopy %s/tmp.fits %s/%s[compress]\n",workdir,outdir,outfits)}' $TMPLIST >> $TMPSH


#END time
if [ $ARCH = "Linux" ] ; then
    SECEND=`date +%s` 
else
    SECEND=`date +"%d %H %M %S"| gawk '{print($1*24*3600+$2*3600+$3*60+$4)}'` 
fi

echo "# End at $SECEND" >> $NDFTOFITSLOG
echo $SECSTART $SECEND | gawk '{printf("# Took %d sec to complete\n",$2-$1)}' >> $NDFTOFITSLOG
echo "# End at $SECEND" 
echo $SECSTART $SECEND | gawk '{printf("# Took %d sec to complete\n",$2-$1)}'

echo "# Log saved as $NDFTOFITSLOG"

exit 0
